@@ -1,7 +1,7 @@
 #!/usr/bin/python
 # vim:fileencoding=UTF-8:ts=4:sw=4:sta:et:sts=4:ai
 
-app_name = 'drivegoogle'
-config_paths = ['~/', './']
+app_name = 'gdrv'
+config_paths = ['~/.config/', './']
 config = None
 #service = None
